	ifndef _EEPROM_asm
		#define _EEPROM_asm

	; ==============================================================		
			list				p=16F819
#include		<P16F819.inc>
#include		"I2C-Servo.h"
#include		"EEPROM.h"
	; ==============================================================		
			udata
EE_TEMP		res				1
	; ==============================================================		
			extern			FSR_TEMP
			extern			Servo0Preset, ServosActive
	; ==============================================================		
_EEPROM_asm	code

	; --------------------------------------------------------------
	; ***	RestoreTrim
	; ***	Restores servo trim values from EEPROM
RestoreTrim
			global			RestoreTrim
			Bank0
			SaveFSR
			SetFSR			Servo0Preset

			banksel			EE_TEMP
			movlw			.8
			movwf			EE_TEMP
			
			banksel			EEADR
			movlw			0x02			
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
RestoreTrim_Loop
			banksel			EECON1
			bsf				EECON1, RD
RestoreTrim_1
			btfsc			EECON1, RD			
			goto				RestoreTrim_1

			banksel			EEDATA
			movf				EEDATA, w			
			movwf			INDF
			incf				FSR, f
			incf				FSR, f
			
			incf				EEADR, f
			incf				EEADR, f
			
			banksel			EE_TEMP
			decfsz			EE_TEMP, f
			goto				RestoreTrim_Loop

RestoreTrim_Done
			Bank0
			RestoreFSR
			return

	; --------------------------------------------------------------
	; ***	RestorePositions
	; ***	Restores servo positions from EEPROM
RestorePositions
			global			RestorePositions
			Bank0
			SaveFSR
			SetFSR			Servo0Preset

			banksel			EE_TEMP
			movlw			.8
			movwf			EE_TEMP
			
			banksel			EEADR
			movlw			0x03
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
RestorePositions_Loop
			banksel			EECON1
			bsf				EECON1, RD
RestorePositions_1
			btfsc			EECON1, RD
			goto				RestorePositions_1
			
			banksel			EEDATA
			incf				FSR, f
			movf				EEDATA, w
			movwf			INDF
			incf				FSR, f
			
			incf				EEADR, f
			incf				EEADR, f
			
			banksel			EE_TEMP
			decfsz			EE_TEMP, f
			goto				RestorePositions_Loop

RestorePositions_Done
			Bank0
			RestoreFSR
			return

	; --------------------------------------------------------------
	; ***	RestoreOnOffMask
	; ***	Restores On / Off BitMask
RestoreOnOffMask
			global			RestoreOnOffMask
			call				ReadOnOffMask
			movwf			ServosActive
			return
			
	; --------------------------------------------------------------
	; ***	SaveTrim
	; ***	Saves actual servo trim values into EEPROM
	; ***	(be sure that GIE is cleared when calling this routine)
SaveTrim
			global			SaveTrim
			Bank0
			SaveFSR
			SetFSR			Servo0Preset

			banksel			EE_TEMP
			movlw			.8
			movwf			EE_TEMP
			
			banksel			EEADR
			movlw			0x02			
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
			bsf				EECON1, WREN

SaveTrim_Loop
			banksel			EEDATA
			movf				INDF, w
			movwf			EEDATA
			incf				FSR, f
			incf				FSR, f
			
			banksel			EECON1
			movlw			0x55
			movwf			EECON2
			movlw			0xAA
			movwf			EECON2
			bsf				EECON1, WR			
SaveTrim_1
			btfsc			EECON1, WR
			goto				SaveTrim_1

			banksel			EEADR
			incf				EEADR, f
			incf				EEADR, f
			
			banksel			EE_TEMP
			decfsz			EE_TEMP, f
			goto				SaveTrim_Loop

SaveTrim_Done
			banksel			EECON1
			bcf				EECON1, WREN
			Bank0
			RestoreFSR
			return
			
	; --------------------------------------------------------------
	; ***	SavePositions
	; ***	Saves actual servo positions into EEPROM
	; ***	(be sure that GIE is cleared when calling this routine)
SavePositions
			global			SavePositions
			Bank0
			SaveFSR
			SetFSR			Servo0Preset
			incf				FSR, f

			banksel			EE_TEMP
			movlw			.8
			movwf			EE_TEMP
			
			banksel			EEADR
			movlw			0x03
			movwf			EEADR

			banksel			EECON1
			bcf				EECON1, EEPGD
			bsf				EECON1, WREN

SavePositions_Loop
			banksel			EEDATA
			movf				INDF, w
			movwf			EEDATA
			incf				FSR, f
			incf				FSR, f
			
			banksel			EECON1
			movlw			0x55
			movwf			EECON2
			movlw			0xAA
			movwf			EECON2
			bsf				EECON1, WR
SavePositions_1
			btfsc			EECON1, WR
			goto				SavePositions_1
			
			banksel			EEADR
			incf				EEADR, f
			incf				EEADR, f
			
			banksel			EE_TEMP
			decfsz			EE_TEMP, f
			goto				SavePositions_Loop

SavePositions_Done
			banksel			EECON1
			bcf				EECON1, WREN
			Bank0
			RestoreFSR
			return

	; --------------------------------------------------------------
	; ***	ReadConfigByte
	; ***	Reads config byte from EEPROM address 0x00
	; ***	and returns it in WREG
ReadConfigByte
			global			ReadConfigByte
			
			banksel			EEADR
			movlw			0x00
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
			bsf				EECON1, RD
ReadConfigByte_1
			btfsc			EECON1, RD
			goto				ReadConfigByte_1
						
			banksel			EEDATA
			movf				EEDATA, w
			Bank0
			return

	; --------------------------------------------------------------
	; ***	WriteConfigByte
	; ***	Writes the byte in WREG as config byte to EEPROM
	; ***	(be sure that GIE is cleared when calling this routine)
WriteConfigByte
			global			WriteConfigByte

			banksel			EEDATA
			movwf			EEDATA
			
			movlw			0x00		
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
			bsf				EECON1, WREN

			movlw			0x55
			movwf			EECON2
			movlw			0xAA
			movwf			EECON2
			bsf				EECON1, WR
WriteConfigByte_1
			btfsc			EECON1, WR
			goto				WriteConfigByte_1
			
			bcf				EECON1, WREN
			Bank0
			return

	; --------------------------------------------------------------
	; ***	ReadOnOffMask
	; ***	Reads Servo On/Off BitMask
ReadOnOffMask
			global			ReadOnOffMask

			banksel			EEADR
			movlw			0x01
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
			bsf				EECON1, RD
ReadOnOffMask_1
			btfsc			EECON1, RD
			goto				ReadOnOffMask_1
			
			banksel			EEDATA
			movf				EEDATA, w
			Bank0
			return

	; --------------------------------------------------------------
	; ***	WriteOnOffMask
	; ***	Writes Servo On/Off BitMask
	; ***	(be sure that GIE is cleared when calling this routine)
WriteOnOffMask
			global			WriteOnOffMask
			
			banksel			EEDATA
			movwf			EEDATA
			
			movlw			0x01		
			movwf			EEADR
			
			banksel			EECON1
			bcf				EECON1, EEPGD
			bsf				EECON1, WREN

			movlw			0x55
			movwf			EECON2
			movlw			0xAA
			movwf			EECON2
			bsf				EECON1, WR
WriteOnOffMask_1
			btfsc			EECON1, WR
			goto				WriteOnOffMask_1
			
			bcf				EECON1, WREN
			Bank0
			return

	; ==============================================================		
	endif			

	end
